Class: Yatte::Syntax::Lexers::Ruby

Inherits:
Yatte::Syntax::Lexer show all
Defined in:
lib/yatte/syntax/lexers/ruby.rb

Constant Summary collapse

KEYWORDS =
%w[
  def end class module if else elsif unless while until do return
  require require_relative include extend
  attr_reader attr_writer attr_accessor
  true false nil self yield raise rescue ensure begin
  then case when in for break next retry redo
  private protected public
].freeze
KEYWORD_RE =
/\b(?:#{KEYWORDS.join("|")})\b/

Method Summary

Methods inherited from Yatte::Syntax::Lexer

detect, filenames, find, inherited, register, registry, rule, tag, #tokenize